Index: src/wp-includes/link-template.php
===================================================================
--- src/wp-includes/link-template.php	(revision 43314)
+++ src/wp-includes/link-template.php	(working copy)
@@ -4329,10 +4329,11 @@
 	$privacy_policy_url = get_privacy_policy_url();
 
 	if ( $privacy_policy_url ) {
-		$link = sprintf(
+		$policy_page_id = (int) get_option( 'wp_page_for_privacy_policy' );
+		$link           = sprintf(
 			'<a class="privacy-policy-link" href="%s">%s</a>',
 			esc_url( $privacy_policy_url ),
-			__( 'Privacy Policy' )
+			get_the_title( $policy_page_id )
 		);
 	}
 
Index: tests/phpunit/tests/link/getThePrivacyPolicyLink.php
===================================================================
--- tests/phpunit/tests/link/getThePrivacyPolicyLink.php	(revision 43314)
+++ tests/phpunit/tests/link/getThePrivacyPolicyLink.php	(working copy)
@@ -71,7 +71,8 @@
 
 	/**
 	 * The function should return a valid link if a privacy policy page has been
 	 * created and set as the `wp_page_for_privacy_policy`.
 	 */
 	public function test_get_the_privacy_policy_link_should_return_valid_link_when_privacy_page_set() {
 		update_option( 'wp_page_for_privacy_policy', self::$privacy_policy_page_id );
@@ -80,6 +81,7 @@
 
 		$this->assertStringStartsWith( '<a', $actual_link );
 		$this->assertContains( self::$privacy_policy_url, $actual_link );
+		$this->assertContains( '>' . WP_TESTS_DOMAIN . ' Privacy Policy</a>', $actual_link );
 		$this->assertStringEndsWith( '</a>', $actual_link );
 	}
 
@@ -71,7 +71,8 @@
 	/**
 	 * The function should return a valid link if a privacy policy page has been
-	 * created and set as the `wp_page_for_privacy_policy`.
+	 * created and set as the `wp_page_for_privacy_policy`. The post title should
+	 * be used as the link text.
 	 */
 	public function test_get_the_privacy_policy_link_should_return_valid_link_when_privacy_page_set() {
